@@ -267,26 +267,21 @@ configure' Ghc ghcpath = do
     else do -- 5.00 and above
       pkgcfg <- runAndReadStdout (escape ghcpath++" --print-libdir")
       let libdir  = escape pkgcfg
-          incdir1 = libdir++"/imports"
-      ok <- doesDirectoryExist incdir1
-      if ok
-        then do
-          fullpath <- fmap escape (which exe ghcpath)
-          let ghcpkg0 = dirname fullpath++"/ghc-pkg-"++ghcversion
-          ok <- doesFileExist ghcpkg0
-          let ghcpkg = if ok then ghcpkg0 else dirname fullpath++"/ghc-pkg"
-       -- pkgs <- runAndReadStdout (ghcpkg++" --list-packages")
-          pkgs <- runAndReadStdout (ghcpkg++" -l")
-          let pkgsOK = filter (\p-> any (`isPrefixOf` p)
-                                        ["std","base","haskell98"])
-                              (deComma pkgs)
-          idirs <- mapM (\p-> runAndReadStdout
-                                  (ghcpkg++" --show-package="
-                                   ++deVersion (ghcsym>=604) p
-                                   ++" --field=import_dirs"))
-                        pkgsOK
-          return config{ includePaths = pkgDirs libdir (nub idirs) }
-        else do ioError (userError ("Can't find ghc includes at "++incdir1))
+      fullpath <- fmap escape (which exe ghcpath)
+      let ghcpkg0 = dirname fullpath++"/ghc-pkg-"++ghcversion
+      ok <- doesFileExist ghcpkg0
+      let ghcpkg = if ok then ghcpkg0 else dirname fullpath++"/ghc-pkg"
+   -- pkgs <- runAndReadStdout (ghcpkg++" --list-packages")
+      pkgs <- runAndReadStdout (ghcpkg++" -l")
+      let pkgsOK = filter (\p-> any (`isPrefixOf` p)
+                                    ["std","base","haskell98"])
+                          (deComma pkgs)
+      idirs <- mapM (\p-> runAndReadStdout
+                              (ghcpkg++" --show-package="
+                               ++deVersion (ghcsym>=604) p
+                               ++" --field=import_dirs"))
+                    pkgsOK
+      return config{ includePaths = pkgDirs libdir (nub idirs) }
  where
     -- ghcDirs only static for ghc < 500; for later versions found dynamically
     ghcDirs n root | n < 400   = [root]
