@@ -36,15 +36,15 @@ import List (intersperse)
 #endif
 
 showdebug (f,(((tpp,ths,thi,tobj),p,s,cpp,pp),i)) =
-  let cppflag = if cpp then "*" else ""
-  in show f ++ cppflag ++ "\n  ppTime= " ++ show tpp
-                       ++ "\n  hsTime= " ++ show ths
-                       ++ "\n  hiTime= " ++ show thi
-                       ++ "\n  oTime=  " ++ show tobj
-     ++ "\n  p= " ++ show p
-     ++ "\n  srcfile= " ++ show s
-     ++ "\n  imports= " ++ show i
-     ++ "\n  preproc= " ++ show (ppExecutableName pp) ++ "\n"
+    show f ++ "\n  cpp= "    ++ show cpp
+           ++ "\n  ppTime= " ++ show tpp
+           ++ "\n  hsTime= " ++ show ths
+           ++ "\n  hiTime= " ++ show thi
+           ++ "\n  oTime=  " ++ show tobj
+           ++ "\n  p= " ++ show p
+           ++ "\n  srcfile= " ++ show s
+           ++ "\n  imports= " ++ show i
+           ++ "\n  preproc= " ++ show (ppExecutableName pp) ++ "\n"
 
 showdep (f,(((tpp,ths,thi,tobj),p,s,cpp,pp),i)) =
   f ++ ": " ++ mix i ++ "\n"
@@ -55,9 +55,10 @@ showdep (f,(((tpp,ths,thi,tobj),p,s,cpp,pp),i)) =
 --   where mix = foldr (\a b-> dotO a ++ ' ':b) "\n"
 --         dotO f = fixFile opts goaldir f (oSuffix opts)
 
-showmake opts goaldir ((f,p,s),i) =
+showmake opts goaldir ((f,p,s,cpp),i) =
   dotO p f ++ ": " ++ s ++ " " ++ mix i
-  where mix = foldr (\(a,p) b-> dotO p a ++ ' ':b) "\n"
+  where mix = foldr (\(a,p) b-> dotO p a ++ ' ':b)
+                    (if cpp then "# -cpp\n" else "\n")
         tmod = if hat opts then ("Hat/"++) else id
         dotO p f = fixFile opts (if null goaldir then p else goaldir)
                                 (tmod f) (oSuffix opts)
