@@ -17,6 +17,8 @@ module Imports
 import Char
 import ListUtil (takeUntil)
 import Language.Preprocessor.Cpphs.CppIfdef (cppIfdef)
+import Language.Preprocessor.Cpphs.Options  (BoolOptions(..)
+                                            ,defaultBoolOptions)
 
 #if !defined(__HASKELL98__)
 #define isAlphaNum isAlphanum
@@ -30,7 +32,10 @@ getImports :: FilePath -- ^ The path to the module
            -> [String] -- ^ A list of imported modules
 getImports fp defines includes = leximports fp
                                  . unlines . map snd
-                                 . cppIfdef fp defs includes False False
+                                 . cppIfdef fp defs includes
+                                            defaultBoolOptions { macros=False
+                                                            , locations=False
+                                                             , warnings=False }
   where
     defs = map (\defn-> let (s,d) = break (=='=') defn in
                         (s, if null d then "1" else tail d)) defines
