@@ -51,27 +51,22 @@ packageDirs config@(CompilerConfig{ compilerStyle=Ghc
     else unsafePerformIO $ do
       pkgcfg <- runAndReadStdout (ghc++" --print-libdir")
       let libdir  = escape pkgcfg
-          incdir1 = libdir++"/imports"
-      ok <- doesDirectoryExist incdir1
-      if ok
-        then do
-          let ghcpkg = matching ghc (ghcPkg ghc (compilerVersion config))
-       -- ghcpkg <- runAndReadStdout
-       --                  ("echo `" ++ ghc ++ " --print-libdir`/bin/ghc-pkg")
-       -- pkgs <- runAndReadStdout (ghcpkg++" --list-packages")
-          pkgs <- runAndReadStdout (ghcpkg++" -l")
-          let (ok,bad) = partition (\p-> elemBy versionMatch p (deComma pkgs))
-                                   packages
-          when (not (null bad))
-               (hPutStrLn stderr ("\nWarning: package(s) "
-                                 ++concat (intersperse ", " bad)
-                                 ++" not available (according to ghc-pkg)"))
-          idirs <- mapM (\p-> runAndReadStdout
-                                  (ghcpkg++" --show-package="++p
-                                   ++" --field=import_dirs"))
-                        ok
-          return (pkgDirs libdir idirs)
-        else do ioError (userError ("Can't find ghc packages at "++incdir1))
+          ghcpkg = matching ghc (ghcPkg ghc (compilerVersion config))
+   -- ghcpkg <- runAndReadStdout
+   --                  ("echo `" ++ ghc ++ " --print-libdir`/bin/ghc-pkg")
+   -- pkgs <- runAndReadStdout (ghcpkg++" --list-packages")
+      pkgs <- runAndReadStdout (ghcpkg++" -l")
+      let (ok,bad) = partition (\p-> elemBy versionMatch p (deComma pkgs))
+                               packages
+      when (not (null bad))
+           (hPutStrLn stderr ("\nWarning: package(s) "
+                             ++concat (intersperse ", " bad)
+                             ++" not available (according to ghc-pkg)"))
+      idirs <- mapM (\p-> runAndReadStdout
+                              (ghcpkg++" --show-package="++p
+                               ++" --field=import_dirs"))
+                    ok
+      return (pkgDirs libdir idirs)
  where
     pkgDirs libdir dirs =
         map (\dir-> if "$libdir" `isPrefixOf` dir
